@@ -2,6 +2,7 @@
 
 /*
  Copyright (C) 2005, 2007, 2008, 2009, 2010, 2011 StatPro Italia srl
+ Copyright (C) 2023 Skandinaviska Enskilda Banken AB (publ)
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -29,7 +30,7 @@
 namespace QuantLib {
 
     //! Indian calendars
-    /*! Holidays for the National Stock Exchange
+    /*! Clearing holidays for the National Stock Exchange
         (data from <http://www.nse-india.com/>):
         <ul>
         <li>Saturdays</li>
@@ -63,11 +64,12 @@ namespace QuantLib {
         <li>Guru Nanak Jayanti</li>
         </ul>
 
+        Note: The holidays Ramzan Id, Bakri Id and Id-E-Milad rely on estimates for 2024-2025.
         \ingroup calendars
     */
     class India : public Calendar {
       private:
-        class NseImpl : public Calendar::WesternImpl {
+        class NseImpl final : public Calendar::WesternImpl {
           public:
             std::string name() const override { return "National Stock Exchange of India"; }
             bool isBusinessDay(const Date&) const override;
